package limone;

/**
 * Encapsulates an AgentID and HostID.  This is enough information to
 * allow a message to be sent to an agent.
 *
 * @author Chien-Liang Fok
 * @version 3/17/2003
 */
public class AgentLocation implements java.io.Serializable{
    
    /**
     *  The AgentID of the Agent this AgentLocation represents.
     */
    AgentID aID;
    
    /**
     * The HostID of the Host this AgentLocation represents.
     */
    HostID hID;
    
    /**
     * Creates an AgentLocation object for the Agent with AgentID aID
     * running on a host with HostID hID.
     *
     * @param aID the AgentID of the Agent this AgentLocation represents.
     * @param hID the HostID of the Agent this AgentLocation represents.
     */
    public AgentLocation(AgentID aID, HostID hID) {
        this.aID = aID;
        this.hID = hID;
    }
    
    /**
     * Determines the equality of this AgentLocation with another object.
     * Another object is equal to this one if the type is AgentLocation,
     * the AgentIDs are equal, and the HostIDs are equal.
     *
     * @param o the object to compare this one to.
     * @return true if o is equal to this object.
     */
    public boolean equals(Object o) {
        if (o instanceof AgentLocation) {
            AgentLocation aLoc = (AgentLocation)o;
            return aLoc.aID.equals(aID)
                && aLoc.hID.equals(hID);
        }
        return false;
    }
    
    /**
     * Returns the AgentID of the Agent this AgentLocation represents.
     *
     * @return the AgentID of the Agent this AgentLocation represents.
     */
    public AgentID agentID() {
        return aID;
    }
    
    /**
     * Returns the HostID of the Host this AgentLocation represents.
     *
     * @return the HostID of the Host this AgentLocation represents.
     */
    public HostID hostID() {
        return hID;
    }
    
    /**
     * Returns a String representation of this class.
     *
     * @return a String representation of this class.
     */
    public String toString() {
        return hID + ": " + aID;
    }
}
