package limone;

import eBeacon.*;
import limone.util.*;

/**
 * The beacon manager takes beacons and updates the neighbor list.
 *
 * @author Chien-Liang Fok
 * @version 03/17/2003
 */
class BeaconManager {
	Agent a;
	NeighborList nl;
	
	public BeaconManager(Agent a) {
		this.a = a;
		this.nl = a.getNeighborList();
	}
	
	/**
	 * This is called by LimoneServer whenever a new beacon arrives.
	 *
	 * @param beacon the beacon that was received.
	 */
	void newBeacon(LimoneBeacon beacon) {
		
		//log("newBeacon(...) called");
		
		Profile[] profiles = beacon.getProfiles();
		
		//log("Got new beacon with " + profiles.length + " profiles");
		
		for (int i = 0; i < profiles.length; i++) {
			
			AgentID aID = ProfileParser.getAgentID(profiles[i]);
			
			//log("Received profile from agent " + aID);
			
			if (nl.contains(aID)) {
				
				Profile currProfile = nl.getProfile(aID);
				
				// If the profile has not changed, simply update the time
				// it was last heard from.  Otherwise, update the profile.
				
				//log("Comparing profile \n" + profiles[i]
				//		+ "\nwith\n" + currProfile);
				
				if (currProfile.equals(profiles[i])) {
					
					//log("Updating time for " + aID);
					nl.updateTime(aID);
					
				} else {
					
					//log("Updating profile for " + aID);
					nl.updateProfile(profiles[i]);
				}
			} else {
				
				//log("The neighblor list did not contain " + aID
				//		+ ", adding profile for " + aID);
				
				// the neighbor list does not contain the profile just received,
				// go ahead and add it
				nl.addProfile(profiles[i]);
			}
		}
	}
	
	private void log(String msg) {
		DebugLogger.log("BeaconManager", msg);
	}
}

