package limone;

import eBeacon.*;
import java.util.*;

/**
 * The engagement policy is a set of profile selectors that determine whether
 * a remote agent is considered relevant.  An agent is considered relevant
 * if at least one of its profile selectors selects the agent's profile.  If
 * no profile selectors are in the engagement policy (the default), all
 * agents are considered relevant.
 *
 * @author Chien-Liang Fok
 * @version 03/17/2003
 */
public class EngagementPolicy
{
	Agent a;
	Vector pss = new Vector();
	
	/**
	 * Creates an empty engagement policy.
	 *
	 * @param a the agent that this policy belongs to.
	 */
	public EngagementPolicy(Agent a) {
		this.a = a;
	}
	
	/**
	 * Adds a profile selector to the engagement policy.
	 */
	public void add(ProfileSelector ps) {
		pss.addElement(ps);
		this.hasChanged();
	}
	
	/**
	 * Removes a profile selector from the engagement policy.
	 */
	public void remove(ProfileSelector ps) {
		pss.removeElement(ps);
		this.hasChanged();
	}
	
	/**
	 * Removes all profile selectors from this list.
	 */
	public void clear() {
		pss.removeAllElements();
		this.hasChanged();
	}
	
	/**
	 * Notify the aquaintance list that the engagement policy has changed.
	 */
	private void hasChanged() {
		a.getAQL().engPolicyChanged();
	}
	
	/**
	 * Determines whether the specified profile is considered relevant.
	 * A profile is relevant if at least one profile selector within this
	 * class selects the profile, or if there are no profile selectors.
	 *
	 * @param p the profile to analyze
	 * @return true if the profile is relevant.
	 */
	public boolean isRelevant(Profile p) {
		if (pss.size() == 0)
			return true;
		
		boolean result = false;
		
		for (int i = 0; !result && i < pss.size(); i++) {
			result = ((ProfileSelector)pss.elementAt(i)).matches(p);
		}
		return result;
	}
}

