package limone;

import java.net.*;
import java.util.*;

/**
 * The HostID is a unique identifier for each LimoneServer.
 *
 * @author Chien-Liang Fok
 * @version 03/17/2003
 */
public class HostID implements java.io.Serializable{
    /**
	 * The address of this host.
	 */
    private InetAddress address;
    
    /**
	 * The single-cast port number being used.
	 */
    private int port;
    
    /**
	 * Create a HostID given the address and port number.
	 */
    public HostID(InetAddress address, int port) {
		this.address = address;
		this.port = port;
    }
    
    /**
	 * Determines whether this HostID is equal to the specified object.
	 *
	 * @param o the object to compare with.
	 * @return true if the object is a HostID with the same address and port.
	 */
    public boolean equals(Object o) {
		if (o instanceof HostID) {
			HostID hostID = (HostID)o;
			return hostID.address.equals(this.address)
				&& hostID.port == this.port;
		}
		return false;
    }
    
    /**
	 * Returns the hashcode of this HostID.
	 *
	 * @return the hashcode of this HostID.
	 */
    public int hashCode() {
		Integer code = new Integer((int)(address.hashCode() + port));
		return code.hashCode();
    }
    
    /**
	 * Returns the address of the LimeLiteServer this HostID represents.
	 * @param the address of the LimeLiteServer.
	 */
    public InetAddress getAddress() {
		return address;
    }
    
    /**
	 * Returns the port of the LimeLiteServer this HostID represents.
	 * @param the port of the LimeLiteServer.
	 */
    public int getPort() {
		return port;
    }
    
    /**
	 * Returns a String representation of this class.
	 *
	 * @return a String representation of this class.
	 */
    public String toString() {
		String addr = address.toString();
		addr = addr.replace('.','-');
		addr = addr.replace('/','-');
		return addr + "-" + port;
    }
}
