package limone;

import eBeacon.*;
import java.io.*;

/**
 * A LimoneBeacon is periodically broadcasted to announce the presence of
 * a LimoneServer and all Agents that are running on top of it.
 *
 * <p> Each beacon contains a list of Profiles representing the
 * agents running on top of the LimoneServer that broadcasted the beacon.
 *
 * @author Chien-Liang Fok
 * @version 03/17/2003
 */
public class LimoneBeacon extends Beacon implements Serializable {
	
    /**
     * The HostID of the host this beacon is being broadcasted from.
     */
    HostID hostID;
    
    /**
     * The singlecast protocol type used.  Possible values include
     * LimoneBeacon.TCP or LimoneBeacon.UDP.
     */
    int type;
    
    /**
     * Default constructor for the beacon.
     */
    public LimoneBeacon() {
        super();
    }
    
	/**
     * Main Beacon Constructor.
     *
     * @param type the single cast protocol, either LimeLiteServer.TCP
     *or LimeLiteServer.UDP.
     * @param hostID the HostID of the host this beacon is being sent by
     * @param aProfiles the profiles of the agents running on top of the host.
     */
    public LimoneBeacon(int type, HostID hostID) {
        super();
        this.type = type;
        this.hostID = hostID;
    }
	
    /**
     * Main Beacon Constructor.
     *
     * @param type the single cast protocol, either LimeLiteServer.TCP
     *or LimeLiteServer.UDP.
     * @param hostID the HostID of the host this beacon is being sent by
     * @param aProfiles the profiles of the agents running on top of the host.
     */
    public LimoneBeacon(int type, HostID hostID, Profile[] aProfiles) {
        super(aProfiles);
        this.type = type;
        this.hostID = hostID;
    }
	
	
    
    /**
     * Returns the singlecast protocol type of the host broadcasting this
     * beacon, either LimeLiteServer.TCP or LimeLiteServer.UDP.
     *
     * @return the singlecast protocol type of the host broadcasting this
     * beacon, either LimeLiteServer.TCP or LimeLiteServer.UDP.
     */
    public int getProtocolType() {
        return type;
    }
    
    /**
     * Returns a String representation of this class.
     *
     * @return a String representation of this class.
     */
    public String toString() {
        StringBuffer sBuff = new StringBuffer("Limone: ")
            .append(hostID.toString());
        sBuff.append(super.toString());
        return sBuff.toString();
    }
}
