package limone;

import java.io.*;

/**
 * Thrown by the LimeLiteServer when it detects an exceptional condition.
 *
 * @author Chien-Liang Fok
 * @version 03/17/2003
 */
public class LimoneException extends Exception {
	
	/**
	 * The exception.
	 */
	private Exception intExp = null;
	
	/**
	 * Specifes whether this exception is internal.
	 */
	private boolean intFlag = false;
	
	/**
	 * Creates a LimeLiteException.
	 */
	public LimoneException() {
		super();
	}
	
	/**
	 * Creates a LimeLiteException.
	 */
	public LimoneException(Exception intExp) {
		this();
		setInternal(intExp);
	}
	
	/**
	 * Creates an exception with a string message.
	 */
	public LimoneException(String s) {
		super(s);
	}
	
	/**
	 * Creates a LimeLiteException.
	 */
	public LimoneException(Exception intExp, String s) {
		this(s);
		setInternal(intExp);
	}
	
	/**
	 * Sets the internal exception.
	 */
	private void setInternal(Exception intExp) {
		this.intExp = intExp;
		intFlag = true;
	}
	
	/**
	 * Returns true if this exception has an internal exception.
	 */
	public boolean hasInternal() {
		return intFlag;
	}
	
	/**
	 * Returns the internal exception.
	 */
	public Exception getInternalException() {
		return intExp;
	}
	
	/**
	 * Returns a String representation of this class.
	 *
	 * @return a String representation of this class.
	 */
	public String toString() {
		String r = super.toString();
		if (intFlag)
			r += ": " + intExp.toString();
		return r;
	}
	
	/**
	 * Prints this exception and its backtrace to the
	 * standard error stream.
	 */
	public void printStackTrace() {
		if (intFlag) {
			System.err.println(super.toString());
			intExp.printStackTrace();
		} else
			super.printStackTrace();
	}
	
	/**
	 * Prints this exception and its backtrace to the
	 * specified print stream.
	 */
	public void printStackTrace(PrintStream s) {
		if (intFlag) {
			s.println(super.toString());
			intExp.printStackTrace(s);
		} else
			super.printStackTrace(s);
	}
	
	/**
	 * Prints this exception and its backtrace to the
	 * specified print writer.
	 */
	public void printStackTrace(PrintWriter s) {
		if (intFlag) {
			s.println(super.toString());
			intExp.printStackTrace(s);
		} else
			super.printStackTrace(s);
	}
}
