package limone;

import eLights.*;

/**
 * A ReactionEvent encapsulates the information generated
 * when a reaction fires.  It contains the reactive pattern of the
 * reaction that fired, the tuple that caused the reaction to fire,
 * and the AgentID of the agent on which the reaction fired.
 *
 * @see AgentID
 * @see ReactivePattern
 *
 * @author Chien-Liang Fok
 * @version 03/17/2003
 */
public class ReactionEvent implements java.io.Serializable{

    /**
     * This is the reactive pattern that matches the tuple.
     */
    ReactivePattern rp;

    /**
     * This is the tuple that caused the reaction to
     * fire.
     */
    ETuple tuple;
    

    /**
     * This is the AgentID of the agent that outed the tuple
     * into their local tuple space.
     */
    AgentID aID;

    /**
     * Creates a ReactionEvent.
     *
     * @param rp the reactive pattern of the reaction that fired.
     * @param tuple the tuple that caused the reaction to fire.
	 * @param aID the ID of the agent that placed the tuple into its tuple
	 * space.
     */
    public ReactionEvent(ReactivePattern rp, ETuple tuple, AgentID aID) {
        this.rp = rp;
		this.tuple = tuple;
		this.aID = aID;
    }
    
    /**
     * Returns the AgentID of the agent on which the reaction fired.
     *
     * @return the AgentID of the agent on which the reaction fired.
     */
    public AgentID agentID() {
        return aID;
    }
    
    /**
     * Returns the ReactivePattern of the reaction that fired.
     *
     * @return The ReactivePattern of the reaction that fired.
     */
    public ReactivePattern rp() {
        return rp;
    }
    
    /**
     * Returns the tuple that caused the reaction to fire.
     *
     * @return The tuple that caused the reaction to fire.
     */
    public ETuple tuple() {
        return tuple;
    }
    
    /**
     * Returns a String representation of this class.
     *
     * @return a String representation of this class.
     */
    public String toString() {
        return rp + ", " + tuple;
    }
}
