package limone;

/**
 * The ReactionID is an unique identifier for each Reaction created by
 * a particular Agent. It is used by an Agent to reliably identify and obtain
 * each of the Reactions it has created.  The ReactionID
 * is also used for determining the equivalence of two Reactions.
 * Two Reactions are equal if both were created by the
 * same Agent and have the same ReactionID.
 *
 * @author Chien-Liang Fok
 * @version 3/17/2003
 */
public class ReactionID implements java.io.Serializable{
	
	private static long currID = 0;
	
	/**
	 * A unique number for each ReactionID.
	 */
	private long id;
	
	/**
	 * Creates a ReactionID.
	 */
	private ReactionID(long id) {
		this.id = id;
	}
	
	/**
	 * Generates a new reaction ID.
	 */
	public static ReactionID generateNew() {
		return new ReactionID(currID++);
	}
	
	/**
	 * Determines if the specified object is equivalent to this ReactionID.
	 */
	public boolean equals(Object o) {
		if (o instanceof ReactionID) {
			ReactionID rID = (ReactionID)o;
			return rID.getEnum() == id;
		}
		return false;
	}
	
	/**
	 * Returns the enumeration value.  This value is unique per agent.
	 */
	public long getEnum() {
		return id;
	}
	
	/**
	 * Returns a String representation of this class.
	 *
	 * @return a String representation of this class.
	 */
	public String toString() {
		return "ReactionID[" + id + "]";
	}
}
