package limone;

import java.io.*;
import eLights.*;
import limone.io.*;

/**
 * The RemoteRequestManager is handles remote requests.  It checks the
 * operation manager to see whether the request is accepted.  If so, then it
 * performs the request and sends the results to the agent to that sent the
 * request.  If rejected, then it sends a rejection back to the requesting
 * agent.
 *
 * @author Chien-Liang Fok
 * @version 3/17/2003
 */
class RemoteRequestManager implements Runnable, Serializable
{
	Agent a;
	
	Queue requestQueue = new Queue();
	
	public RemoteRequestManager(Agent a) {
		this.a = a;
		new Thread(this).start();
	}
	
	public void processRequest(Request r) {
		requestQueue.add(r);
	}
	
	public void run() {
		
		LimoneServer ls = LimoneServer.getServer();
		
		while(true) {
			
			log("Waiting for next request");
			
			// get the next request
			Request r = (Request)requestQueue.remove();
			
			log("processing next request");
			
			Reply rep = null;  // the reply message
			
			boolean sendReject = false;
			
			if (a.opMgr.acceptRequest(r)){
				switch(r.getType()) {
					
					case Message.OUT:
						
						log("Received an OUT request");
						
						a.tupleSpace.out(r.getTuple());
						
						log("Formulating OUT reply");
						
						rep = new Reply(
							r.getType(),
							r.getID(),
							r.getReplyHostID(),
							r.getReplyAgentID(),
							a.getAgentID(),
							false);
						
						break;
						
					case Message.INP:
						
						log("Received an INP request");
						
						rep = new Reply(
							r.getType(),
							r.getID(),
							r.getReplyHostID(),
							r.getReplyAgentID(),
							a.getAgentID(),
							a.tupleSpace.inp(r.getTemplate()));
						
						break;
						
					case Message.INGP:
						
						log("Received an INGP request");
						
						rep = new Reply(
							r.getType(),
							r.getID(),
							r.getReplyHostID(),
							r.getReplyAgentID(),
							a.getAgentID(),
							a.tupleSpace.ingp(r.getTemplate()));
						
						break;
						
					case Message.RDP:
						
						log("Received an RDP request");
						
						rep = new Reply(
							r.getType(),
							r.getID(),
							r.getReplyHostID(),
							r.getReplyAgentID(),
							a.getAgentID(),
							a.tupleSpace.rdp(r.getTemplate()));
						
						break;
						
					case Message.RDGP:
						
						log("Received an RDGP request");
						
						rep = new Reply(
							r.getType(),
							r.getID(),
							r.getReplyHostID(),
							r.getReplyAgentID(),
							a.getAgentID(),
							a.tupleSpace.rdgp(r.getTemplate()));
						
						break;
						
					case Message.REGISTER_REACTIVE_PATTERN:
						
						log("Received register a reactive pattern request");
						a.getRL().addRP(r.getRP());
						
						/*if (a.getRL().addRP(r.getRP())) {
							rep = new Reply(
								r.getType(),
								r.getEnum(),
								r.getReplyHostID(),
								r.getReplyAgentID(),
								a.getAgentID(),
								false);
						} else
						 sendReject = true;*/
						
						
						break;
						
					case Message.DEREGISTER_REACTIVE_PATTERN:
						
						log("Received an deregister rp request");
						
						a.getRL().removeRP(r.getRP());
						
						/*rep = new Reply(
							r.getType(),
							r.getEnum(),
							r.getReplyHostID(),
							r.getReplyAgentID(),
							a.getAgentID(),
						 false);*/
						
						
						break;
				}
			} else
				sendReject = true;
			
			
			if (sendReject) {
				rep = new Reply(r.getType(),
								r.getID(),
								r.getReplyHostID(),
								r.getReplyAgentID(),
								a.getAgentID(),
								true);  // indicates rejection
			}
			
			// send the reply
			if (r.getType() != Message.REGISTER_REACTIVE_PATTERN
				&& r.getType() != Message.DEREGISTER_REACTIVE_PATTERN)
				ls.sendMessage(rep);
		}
	}
	
	void log(String msg) {
		DebugLogger.log("RemoteRequestManager", msg);
	}
}

