package limone.io;

import java.io.*;
import eLights.*;
import limone.*;

/**
 * This message instructions the LimeLiteServer to load an Agent.
 * It is used by the Launcher to communicate with a LimeLiteServer.
 *
 * @author Chien-Liang Fok
 * @version 3/17/2003
 */
public class LoadAgentRequest implements Message, Serializable
{
	/**
	 * The HostID of the LimoneServer on which the requesting agent is
	 * residing on.
	 */
	HostID dHostID;
	
	/**
	 * The user-defined name of the agent that should be loaded.
	 */
	String agentName;
	
	/**
	 * The class name of the agent.
	 */
	String agentClass;
	
	/**
	 * The default constructor does not do anything.
	 */
	public LoadAgentRequest() {
	}
	
	/**
	 * Creates a ReactionResults object.
	 *
	 * @param destHostID the HostID of the LimoneServer on which the
	 * destination agent is residing on.
	 * @param agentClass the name of the agent's class file
	 * @param agentName the name of the agent
	 */
	public LoadAgentRequest(HostID destHostID, String agentClass,
							String agentName) {
		this.dHostID = destHostID;
		this.agentName = agentName;
		this.agentClass = agentClass;
	}
	
	/**
	 * Returns the type of the message.  Type possible
	 * types are defined within Message.
	 *
	 * @return the type of the message.  Type possible
	 * types are defined within Message.
	 */
    public int getType(){
		return LOAD_AGENT;
	}
    
    /**
	 * Returns the destination hostID of the host that this message
	 * should be sent to.
	 *
	 * @return the destination hostID of the host that this message
	 * should be sent to.
	 */
    public HostID getDestHostID() {
		return dHostID;
	}
    
    /**
	 * Returns null (does not apply).
	 */
    public AgentID getDestAgentID(){
		return null;
	}
	
	/**
	 * Returns null (does not apply).
	 */
	public AgentID getSourceAgentID() {
		return null;
	}
	
	/**
	 * Returns the class name of the agent.
	 */
	public String getAgentClassName() {
		return agentClass;
	}
	
	/**
	 * Returns the user-defined name of the agent.
	 */
	public String getAgentName() {
		return agentName;
	}
	
	public String toString() {
		return "LoadAgentRequest";
	}
}

