package limone.io;

import java.io.*;
import eLights.*;
import limone.*;

/**
 * This message holds the results of a reaction.
 *
 * @author Chien-Liang Fok
 * @version 3/17/2003
 */
public class ReactionResults implements Message, Serializable
{
	/**
	 * The AgentID of the agent that this request is destined to.
	 */
	AgentID dAgentID;
	
	/**
	 * The AgentID of the agent that sent this result.
	 */
	AgentID sAgentID;
	
	/**
	 * The HostID of the LimoneServer on which the requesting agent is
	 * residing on.
	 */
	HostID dHostID;
	
	/**
	 * The Reaction ID of the reaction that fired.
	 */
	ReactionID rID;
	
	/**
	 * The tuple that caused the reaction to fire.
	 */
	ETuple matchingTuple;
	
	/**
	 * The default constructor does not do anything.
	 */
	public ReactionResults() {
	}
	
	/**
	 * Creates a ReactionResults object.
	 *
	 * @param destAgentID the HostID of the LimoneServer on which the
	 * destination agent is residing on.
	 * @param destHostID the HostID of the LimoneServer on which the
	 * destination agent is residing on.
	 * @param sAgentID the AgentID of the agent that sent this result.
	 * @param rID the reaction ID of the reaction that fired
	 * @param matchingTuple the tuple that caused the reaction to fire
	 */
	public ReactionResults(HostID destHostID, AgentID destAgentID,
						   AgentID sAgentID, ReactionID rID,
						   ETuple matchingTuple) {
		this.dHostID = destHostID;
		this.dAgentID = destAgentID;
		this.sAgentID = sAgentID;
		this.rID = rID;
		this.matchingTuple = matchingTuple;
	}
	
	/**
	 * Returns the type of the message.  Type possible
	 * types are defined within Message.
	 *
	 * @return the type of the message.  Type possible
	 * types are defined within Message.
	 */
    public int getType(){
		return REACTION_RESULTS;
	}
    
    /**
	 * Returns the destination hostID of the host that this message
	 * should be sent to.
	 *
	 * @return the destination hostID of the host that this message
	 * should be sent to.
	 */
    public HostID getDestHostID() {
		return dHostID;
	}
    
    /**
	 * Returns the destination agentID of the agent that this message
	 * should be sent to.
	 *
	 * @return the destination agentID of the agent that this message
	 * should be sent to.
	 */
    public AgentID getDestAgentID(){
		return dAgentID;
	}
	
	/**
	 * Returns the agentID of the agent that sent this result.
	 */
	public AgentID getSourceAgentID() {
		return sAgentID;
	}
	
	/**
	 * Returns the reaction ID of the reaction that fired.
	 */
	public ReactionID getRxnID() {
		return rID;
	}
	
	/**
	 * Returns the tuple that fired the reaction.
	 */
	public ETuple getTuple() {
		return matchingTuple;
	}
	
	public String toString() {
		return "ReactionResults";
	}
}
