package limone.io;

import java.io.*;
import java.net.*;
import java.util.*;
import limone.*;

/**
 * Sends messages to other LimeLiteServers using TCP.
 * A TCP connection to another host is kept alive until a
 * disconnect occurs <i>and</i> a message is sent to the
 * disconnected agent.
 *
 * @author Chien-Liang Fok
 * @version 3/17/2003
 */
public class TCPMessageSender implements MessageSender,
    java.io.Serializable {
    
    /**
     * Creates a TCPMessageSender.
     */
    public TCPMessageSender() {
    }
    
    /**
     * Forces the TCPMessageSender to close all sockets and stop
     * functioning.
     */
    public void kill() {
    }
    
    /**
     * Returns the singlecast protocol type of this MessageSender,
     * which is LimeLiteServer.TCP.
     *
     * @return the singlecast protocol type of this MessageSender,
     * which is LimeLiteServer.TCP.
     */
    public int getProtocolType() {
        return LimoneServer.TCP;
    }
    
    /**
     * Sends a message via a TCP socket.
     *
     * @param msg the message to be sent.
     */
    public void sendMessage(Message msg) {
                        
        // Obtain the hostID of the destination host
        HostID dest = msg.getDestHostID();
        
        if (dest != null) {
            
            // open a TCP socket to the destination host
            try {
				log("Opening TCP socket to destination host \naddress:"
						+ dest.getAddress() + "\n port: " + dest.getPort());
                Socket socket = new Socket(dest.getAddress(), dest.getPort());
                socket.setTcpNoDelay(true);
                
                OutputStream os = socket.getOutputStream();
                InputStream is = socket.getInputStream();
                
                ObjectOutputStream oos = new ObjectOutputStream(os);
                ObjectInputStream ois = new ObjectInputStream(is);
                
				log("Sending the object to the destination.");
                oos.writeObject(msg);
                oos.flush();
                os.flush();
                
				log("Closing the socket to the destination host.");
                socket.close();
                
            } catch(Exception e) {
                e.printStackTrace();
            }
        } else
			log("The destination of the message is null!");
    }
	
	void log(String msg) {
		DebugLogger.log("TCPMessageSender", msg);
	}
}
