package limone.io;

import java.io.*;
import java.net.*;
import limone.*;

/**
 * Listens on a UDP port for messages destined to this agent.
 *
 * @author Chien-Liang Fok
 * @version 3/17/2003
 */
public class UDPMessageReceiver implements MessageReceiver,
    Runnable, Serializable {
    
    private boolean done = false;
    private LimoneServer lls;
    private DatagramSocket socket = null;
    
    private int port;
    
    /**
     * This message receiver listens for UDP connections
     * and reads in commands from them.
	 *
	 * @param port the port on which to listen for connections
     */
    public UDPMessageReceiver(int port)
        throws LimoneServerException {
        this.port = port;
		
        this.lls = LimoneServer.getServer();;
        
        
        try{
            // listen for datagram packets on the given port
            socket = new DatagramSocket(port);
        }
        catch(Exception e) {
            throw new LimoneServerException(
                "Could not create a DatagramSocket on port " + port);
        }
        
        new Thread(this).start();
    }
    
    /**
     * Stop the operation of the Message Receiver.
     * Once the MessageReceiver has been terminated, it can no
     * longer resume operation and should be discarded.
     */
    public void kill() {
        
        // allow this thread to terminate
        done = true;
        
        // close the socket
        try {
            socket.close();
        } catch(Exception e) {}
    }
    
    public void run() {
        ObjectInputStream ois = null;
        ByteArrayInputStream bis = null;
        DatagramPacket packet;
        
        while(!done) {
            try {
                // read in data from the multicast socket
                byte[] buf = new byte[500000];
                packet = new DatagramPacket(buf, buf.length);
                socket.receive(packet);
    
                // convert the data read in into an object
                bis = new ByteArrayInputStream(packet.getData());
                ois = new ObjectInputStream(bis);
                
                Object o = ois.readObject();
                if (o!= null && o instanceof Message) {
                    final Message msg = (Message)o;
                    lls.newMsg(msg);
                }
            }
            catch(Exception e) {
                if (!done)
                    e.printStackTrace();
            }
        }
    }
}
