package limone.io;

import java.io.*;
import java.net.*;
import limone.*;

/**
 * This class controls the sending of a message via a UDP datagram
 * socket.
 *
 * @author Chien-Liang Fok
 * @version 3/17/2003
 */
public class UDPMessageSender implements MessageSender, java.io.Serializable {
    
    private DatagramSocket socket = null;
    
    /**
     * Creates a UDPMessageSender.
     */
    public UDPMessageSender() {
        try {
            socket = new DatagramSocket();
        } catch(Exception e) {
            e.printStackTrace();
            System.exit(0);
        }
    }
    
    /**
     * Forces the UDPMessageSender to close all sockets and stop
     * functioning.
     */
    public void kill() {
        try {
            socket.close();
        } catch(Exception e) {}
    }
    
    /**
     * Sends a message via a UDP socket.
     *
     * @param msg the message to be sent.
     */
    public void sendMessage(Message msg) {
        
        try {
            // initialize the socket on any random port
            socket=new DatagramSocket();
            
            // serialize the message
            ByteArrayOutputStream bos= new ByteArrayOutputStream();
            ObjectOutputStream out = new ObjectOutputStream(bos);
            out.writeObject(msg);
            out.flush();
            out.close();
            
            // extract out the destination information
            HostID hostID = msg.getDestHostID();
            
            // create the message Packet
            //log("Creating the datagram packet.");
            //log("Address [InetAddress] = " + hostID.getAddress());
            //log("Port = " + hostID.getPort());
            DatagramPacket msgPacket = new DatagramPacket(
                bos.toByteArray(),bos.size(), hostID.getAddress(),
                hostID.getPort());
            //log("Created the datagram packet.");
            
            // send the message packet
            //log("Sending the message");
            socket.send(msgPacket);
            //log("Message sent.");
        }
        catch(Exception ae) {
            ae.printStackTrace();
        }
        finally {
            try {
                socket.close();
            } catch(Exception e){}
        }
    }
    
    /**
     * Returns the singlecast protocol type of this MessageSender,
     * which is LimeLiteServer.UDP.
     *
     * @return the singlecast protocol type of this MessageSender,
     * which is LimeLiteServer.UDP.
     */
    public int getProtocolType() {
        return LimoneServer.UDP;
    }
    

}
